.. _developer-guide:

===============
Developer Guide
===============

**Contents**

.. toctree::
   :maxdepth: 1

   contrib_guide.rst
   jupyter_enhancement_proposals.rst
   releasing.rst

Whether you are a new contributor or a seasoned developer, we're pleased that
you are working on Jupyter. We hope you find the Developer Guide useful.
Please feel free to suggest changes or ask questions about the content. Thanks for your contribution!

If you are interested in installing a specific project from source, each
project has documentation on ReadTheDocs. For example, IPython documentation
can be found on `ReadTheDocs <https://ipython.readthedocs.io/en/latest/install/install.html#installation-from-source>`_.
Most of our packages can be installed from the source directory like any other
Python package, by running:

::

    pip install .

The Jupyter notebook needs some extra pieces to build Javascript components;
the information about that is in the `notebook contributor documentation <https://jupyter-notebook.readthedocs.io/en/latest/contributing.html#setting-up-a-development-environment>`_.
